``b2luigi`` Features
--------------------

Once you have your first task tree setup, ``(b2)luigi`` has many features, that make your live easier.
From leveraging batch systems, setting up different environments, keeping track over many parameters and files, there are many features to keep in mind.
In the following sections some of the important features are explained in more detail.
Also checkout our :ref:`examples-label` and :ref:`starterkit_label` for some working examples.

.. toctree::
    :maxdepth: 2

    features/luigi_features
    features/run_modes
    features/batch
    features/parameters
    features/input_output
    features/settings
